#
# spec file for package python-yq
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define skip_python2 1
Name:           python-yq
Version:        3.2.2
Release:        bp156.2.3.1
Summary:        Command-line YAML processor - jq wrapper for YAML documents
License:        Apache-2.0
URL:            https://github.com/kislyuk/yq
Source:         https://files.pythonhosted.org/packages/source/y/yq/yq-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       jq
Requires:       python-PyYAML >= 5.3.1
Requires:       python-argcomplete >= 1.8.1
Requires:       python-tomlkit >= 0.11.6
Requires:       python-xmltodict >= 0.11.0
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML >= 5.3.1}
BuildRequires:  %{python_module argcomplete >= 1.8.1}
BuildRequires:  %{python_module tomlkit >= 0.11.6}
BuildRequires:  %{python_module xmltodict >= 0.11.0}
BuildRequires:  jq
# /SECTION
%python_subpackages

%description
yq: Command-line YAML processor - jq wrapper for YAML documents

%prep
%autosetup -p1 -n yq-%{version}
sed -i "/setup_requires/d" setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/yq
%python_clone -a %{buildroot}%{_bindir}/xq
%python_clone -a %{buildroot}%{_bindir}/tomlq
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative yq
%python_install_alternative xq
%python_install_alternative tomlq

%postun
%python_uninstall_alternative yq
%python_uninstall_alternative xq
%python_uninstall_alternative tomlq

%check
export LANG=en_US.UTF-8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python test/test.py -v

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/yq
%python_alternative %{_bindir}/xq
%python_alternative %{_bindir}/tomlq
%{python_sitelib}/yq*

%changelog
* Wed Sep  4 2024 Daniel Garcia <daniel.garcia@suse.com>
- Build with python 3.11 (bsc#1229853).
* Fri Jul 21 2023 Matej Cepl <mcepl@suse.com>
- It seems that tomlkit > 0.8.0 is not needed after all
  (jsc#PED-5095).
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.2:
  * Allow XML documents to be streamed with –xml-item-depth
* Thu Apr  6 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 3.2.1:
  * Use tomlkit instead of toml
  * Add security policy
  * Documentation and release infrastructure improvements
* Wed Mar  1 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.1:
  * Handle TOML datetimes. Fixes #160
  * Test and documentation improvements
* Tue Jul 26 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.1.0:
    Use configurable output grammar, compatible with YAML 1.1
- Update to 3.0.2:
  - Expand merge keys (https://yaml.org/type/merge.html). This is
    a YAML 1.1 specific behavior, but will be accommodated in yq
    due to its widespread use and low likelihood of accidental
    invocation.
- Update to 3.0.1:
  - yq now uses the YAML 1.2 grammar when parsing and rendering
    YAML documents. This means bare literals like “on”, “no”,
    and “12:34:56” are interpreted as strings. (Fix interrupted
    release)
- Removed upstreamed e37a7981b505aa0fd60d062ca81fd7b23715233e.patch
* Fri Feb 25 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.14.0
  * Support binary and set tags.
- Add e37a7981b505aa0fd60d062ca81fd7b23715233e.patch
  Fix expected output of a test case
* Fri Dec 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.13.0
  * Improve YAML loading performance by using CSafeLoader where available
  * Fix tests
- Drop upstream merged skip-broken-test.py
* Thu May  6 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.12.0
  * Add TOML support and the tomlq CLI utility to access it
  * Drop Python 2.7 support
  * Parse correctly when empty string is passed as jq_filter
  * Better handling of jq_filter and files arguments
- Add skip-broken-test.py
* Tue Jul 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.10.1
  * Add support for xmltodict force_list definition for xq CLI (#95)
  * Support explicit doc markers (#93)
  * Ensure proper ordering of help messages (#90)
- Drop already merged pyaml53.patch
* Thu Mar  5 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.10.0:
  * Add support for in-place editing (yq -yi)
  * Add argcomplete integration
  * Docs: Migrate from RTD to gh-pages
  * Add -Y/--yaml-roundtrip for preserving YAML styles and tags
- Add patch to work with new PyYAML:
  * pyaml53.patch
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.8.1:
  * Filter out -C and separate commingled yq and jq short options
  * Set default block sequence indentation to 2 spaces, –indentless for 0
  * Make main body of yq callable as a library function
  * Test and release infrastructure updates
* Tue May 21 2019 John Vandenberg <jayvdb@gmail.com>
- Add runtime dependency jq
- Set LANG in %%check to make tests pass on Leap builds
* Wed Mar 27 2019 Matej Cepl <mcepl@suse.com>
- Run test suite at least for Python 3
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 2.7.2
  * xq: Introduce –xml-dtd and –xml-root.
  * TOML support is optional and experimental
  * TOML support with the tq executable entry point.
  * Disallow argparse abbreviated options.
  * Parse unrecognized tags instead of dropping them.
  * Ignore unrecognized YAML tags instead of crashing.
  * xq -x: Raise understandable error on non-dict conversion failure.
  * Support XML parsing with xmltodict.
  * Fix for the –from-file/-f argument: Re-route jq_filter to files
    when using –from-file.
  * Parse and pass multiple positional-consuming jq args.
  * Support jq arguments that consume subsequent positionals.
  * Support bare YAML dates and times.
- package LICENSE
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Dec 20 2017 tbechtold@suse.com
- Initial packaging (version 2.3.3)
